@@ -284,7 +284,6 @@ calibrateItems <- function(df, iter=2000L, chains=4L, varCorrection=3.0, maxAtte
   df <- filterGraph(df)
   df <- normalizeData(df)
   vCol <- match(paste0('pa',1:2), colnames(df))
-  varCorrection <- 3.0
   result <- expand.grid(item=colnames(df[,-vCol]),
                         iter=NA,
                         divergent=NA, treedepth=NA, low_bfmi=NA, n_eff=NA, Rhat=NA,
@@ -409,6 +408,7 @@ outlierTable <- function(data, x, threshold=0.5) {
              item=data$item[offset],
              pick=data$pick[offset],
              k=pareto_k_values(x)[ids])
+  df <- df[!duplicated(offset),]
   for (k in paste0('pa',1:2)) {
     levels(df[[k]]) <- palist
     class(df[[k]]) <- 'factor'
